.. _api_fileio_fileutils:

IO Utilities (:mod:`pydicom.fileutil`)
======================================

.. currentmodule:: pydicom.fileutil

Utilities for dataset I/O.

.. autosummary::
   :toctree: generated/

   absorb_delimiter_item
   find_bytes
   find_delimiter
   length_of_undefined_length
   read_undefined_length_value
